Summarise estimate types by result type in a summarised_result object
Source:R/checkout.R
summaryEstimates.RdFor each unique `result_type` in the result settings, reports which estimate names are present along with their row counts and percentage of the total.
Arguments
- result
A `summarised_result` object.
- output
A single character string specifying where to send the output. It can be:
"console"to print the summary in the console."text"to return the summary as a character string."show"to display the result in the viewer (HTML format).Otherwise
outputwill be used as the name of an'.md'file to write the report to.